@@ -8,6 +8,7 @@ import hashlib
 import json
 import math
 import os
+import re
 import sys
 import threading
 import time
@@ -21,8 +22,9 @@ from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import Gtk
 
-from kuwo import Config
-from kuwo import Utils
+from . import Config
+from . import Utils
+from . import DES
 
 IMG_CDN = 'http://img4.kwcdn.kuwo.cn/'
 ARTIST = 'http://artistlistinfo.kuwo.cn/mb.slist?'
@@ -33,7 +35,6 @@ SONG = 'http://antiserver.kuwo.cn/anti.s?'
 
 CHUNK = 16384                # 2**14, 16k, chunk size for file downloading 
 CHUNK_TO_PLAY = 2097152      # 2**21, 2M, min size to emit can-play signal
-CHUNK_APE_TO_PLAY = 8388608  # 2**23, 8M
 CHUNK_MV_TO_PLAY = 8388608   # 2**23, 8M
 MAXTIMES = 3                 # time to retry http connections
 TIMEOUT = 30                 # HTTP connection timeout
@@ -712,7 +713,6 @@ def get_radio_songs(nid, offset):
 def get_song_link(song, conf, use_mv=False):
     '''song is song_info dict.
 
-    @conf, is used to to read conf['use-ape'], conf['use-mkv'],
     conf['song-dir'] and song['mv-dir'].
     use_mv, default is False, which will get mp3 link.
     Return:
@@ -722,24 +722,44 @@ def get_song_link(song, conf, use_mv=False):
               music source link, returns ''
      @song_path: target abs-path this song will be cached.
     '''
+    audio_brs = ['128kmp3', '192kmp3', '320kmp3', '2000kflac']
+    audio_formats = ['MP3128', 'MP3192', 'MP3H', 'AL']
+    video_formats = ['MP4L', 'MP4']
     if use_mv:
-        ext = 'mkv|mp4' if conf['use-mkv'] else 'mp4'
-    else:
-        ext = 'ape|mp3' if conf['use-ape'] else 'mp3'
-    url = ''.join([
-        SONG,
-        'response=url&type=convert_url&format=',
-        ext,
-        '&rid=MUSIC_',
-        str(song['rid']),
+        if video_formats[1] in song.get('formats', '') and conf['video'] == 1:
+            br = video_formats[1]
+        else:
+            br = video_formats[0]
+        ext = 'mp4'
+        url = ''.join([
+            'user=359307055300426&prod=kwplayer_ar_6.4.8.0',
+            '&corp=kuwo&source=kwplayer_ar_6.4.8.0_kw.apk&p2p=1',
+            '&type=convert_mv_url2&rid=', str(song['rid']),
+            '&quality=', br,
+            '&network=WIFI&mode=audition&format=mp4&br=&sig='
         ])
-    song_name = (''.join([
-        song['artist'],
-        '-',
-        song['name'],
-        '.',
-        ext,
-        ])).replace('/', '+')
+    else:
+        ext = 'mp3'
+        if conf['audio'] == 3 and audio_formats[3] in song.get('formats', ''):
+            br = audio_brs[3]
+            ext = 'flac'
+        elif conf['audio'] >= 2 and audio_formats[2] in song.get('formats', ''):
+            br = audio_brs[2]
+        elif conf['audio'] >= 1 and audio_formats[1] in song.get('formats', ''):
+            br = audio_brs[1]
+        else:
+            br = audio_brs[0]
+        url = ''.join([
+            'user=359307055300426&prod=kwplayer_ar_6.4.8.0&corp=kuwo',
+            '&source=kwplayer_ar_6.4.8.0_kw.apk&p2p=1&type=convert_url2',
+            '&br=', br,
+            '&format=mp3|flac|aac&sig=0&rid=', str(song['rid']),
+            '&network=WIFI'
+        ])
+
+    url = 'http://mobi.kuwo.cn/mobi.s?f=kuwo&q=' + DES.base64_encrypt(url)
+    song_name = (''.join(
+        [song['artist'], '-', song['name'], '.', ext, ])).replace('/', '+')
     if use_mv:
         song_path = os.path.join(conf['mv-dir'], song_name)
     else:
@@ -749,7 +769,10 @@ def get_song_link(song, conf, use_mv=False):
     req_content = urlopen(url)
     if not req_content:
         return (False, '', song_path)
-    song_link = req_content.decode()
+    match = re.search('url=(\S+)\s', req_content.decode())
+    if not match:
+        return (False, '', song_path)
+    song_link = match.group(1)
     if len(song_link) < 20:
         return (False, '', song_path)
     song_list = song_link.split('/')
@@ -802,14 +825,12 @@ class AsyncSong(GObject.GObject):
         '''Get the actual link of music file.
 
         If higher quality of that music unavailable, a lower one is used.
-        like this:
-        response=url&type=convert_url&format=ape|mp3&rid=MUSIC_3312608
         '''
         async_call(self._download_song, empty_func, song, use_mv)
 
     def _download_song(self, song, use_mv):
-        cached, song_link, song_path = get_song_link(
-                song, self.app.conf, use_mv=use_mv)
+        cached, song_link, song_path = get_song_link(song, self.app.conf,
+                                                     use_mv=use_mv)
         # temp file to store data
         tmp_song_path = song_path + '.part'
 
@@ -824,15 +845,14 @@ class AsyncSong(GObject.GObject):
             self.emit('network-error', song_link)
             return
 
-        chunk_to_play = CHUNK_TO_PLAY
-        if self.app.conf['use-ape']:
-            chunk_to_play = CHUNK_APE_TO_PLAY
         if use_mv:
             chunk_to_play = CHUNK_MV_TO_PLAY
+        else:
+            chunk_to_play = CHUNK_TO_PLAY
 
         for retried in range(MAXTIMES):
             try:
-                req = request.urlopen(song_link)
+                req = request.urlopen(song_link, timeout=TIMEOUT)
                 received_size = 0
                 can_play_emited = False
                 content_length = int(req.headers.get('Content-Length'))
@@ -849,10 +869,10 @@ class AsyncSong(GObject.GObject):
                     percent = received_size / content_length
                     self.emit('chunk-received', percent)
                     # this signal only emit once.
-                    if ((received_size > chunk_to_play or percent > 40) and
+                    if ((received_size > chunk_to_play or percent > 0.4) and
                             not can_play_emited):
-                        can_play_emited = True
                         self.emit('can-play', tmp_song_path)
+                        can_play_emited = True
                     if not chunk:
                         break
                     fh.write(chunk)
