@@ -11,8 +11,8 @@ from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Pango
 
-from kuwo import Config
-from kuwo import Widgets
+from . import Config
+from . import Widgets
 
 _ = Config._
 
@@ -22,16 +22,16 @@ ShortcutMode = Config.ShortcutMode
 
 DISNAME_COL, NAME_COL, KEY_COL, MOD_COL = list(range(4))
 
+
 class NoteTab(Gtk.Box):
+
     def __init__(self):
         super().__init__(orientation=Gtk.Orientation.VERTICAL)
         self.set_border_width(10)
 
-class ColorButton(Gtk.ColorButton):
-    def __init__(self, color):
-        super().__init__()
 
 class ColorBox(Gtk.Box):
+
     def __init__(self, label, conf, color_name, use_margin=False):
         super().__init__()
         self.conf = conf
@@ -56,7 +56,9 @@ class ColorBox(Gtk.Box):
             color_rgba.alpha = 0.999
         self.conf[self.color_name] = color_rgba.to_string()
 
+
 class FontBox(Gtk.Box):
+
     def __init__(self, label, conf, font_name, use_margin=True):
         super().__init__()
         self.conf = conf
@@ -65,10 +67,13 @@ class FontBox(Gtk.Box):
         self.pack_start(left_label, False, True, 0)
 
         font_button = Gtk.SpinButton()
-        adjustment = Gtk.Adjustment(conf[font_name], 4, 72, 1, 10)
+        if Config.GTK_GE_312:
+            adjustment = Gtk.Adjustment(conf[font_name], 4, 72, 1, 10, 1)
+        else:
+            adjustment = Gtk.Adjustment(conf[font_name], 4, 72, 1, 10)
         adjustment.connect('value-changed', self.on_font_set)
+        adjustment.set_value(conf[font_name])
         font_button.set_adjustment(adjustment)
-        font_button.set_value(conf[font_name])
         self.pack_end(font_button, False, True, 0)
 
         if use_margin:
@@ -79,6 +84,7 @@ class FontBox(Gtk.Box):
 
 
 class ChooseFolder(Gtk.Box):
+
     def __init__(self, parent, conf_name, toggle_label):
         super().__init__(orientation=Gtk.Orientation.VERTICAL)
         self.props.margin_left = MARGIN_LEFT
@@ -126,17 +132,16 @@ class ChooseFolder(Gtk.Box):
 
 
 class Preferences(Gtk.Dialog):
+
     def __init__(self, app):
         self.app = app
-        super().__init__(
-                _('Preferences'), app.window, 0,
-                (Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE,))
+        super().__init__(_('Preferences'), app.window, 0,
+                         (Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE,))
         self.set_modal(True)
         self.set_transient_for(app.window)
         self.set_default_size(600, 320)
         self.set_border_width(5)
         box = self.get_content_area()
-        #box.props.margin_left = MARGIN_LEFT
 
         notebook = Gtk.Notebook()
         box.pack_start(notebook, True, True, 0)
@@ -165,8 +170,7 @@ class Preferences(Gtk.Dialog):
 
         dark_theme_button = Gtk.CheckButton(_('Use dark theme'))
         dark_theme_button.set_active(app.conf['use-dark-theme'])
-        dark_theme_button.connect(
-                'toggled', self.on_dark_theme_button_toggled)
+        dark_theme_button.connect('toggled', self.on_dark_theme_button_toggled)
         generic_box.pack_start(dark_theme_button, False, False, 0)
 
         # format tab
@@ -175,32 +179,47 @@ class Preferences(Gtk.Dialog):
 
         audio_label = Widgets.BoldLabel(_('Prefered Audio Format'))
         format_box.pack_start(audio_label, False, False, 0)
-        radio_mp3 = Gtk.RadioButton(_('MP3 (faster)'))
-        radio_mp3.props.margin_left = MARGIN_LEFT
-        radio_mp3.connect('toggled', self.on_audio_toggled)
-        format_box.pack_start(radio_mp3, False, False, 0)
-        radio_ape = Gtk.RadioButton(_('APE (better)'))
-        radio_ape.join_group(radio_mp3)
-        radio_ape.props.margin_left = MARGIN_LEFT
-        radio_ape.set_active(app.conf['use-ape'])
-        radio_ape.connect('toggled', self.on_audio_toggled)
-        format_box.pack_start(radio_ape, False, False, 0)
+        audio_128k = Gtk.RadioButton(_('128K MP3 (Fastest)'))
+        audio_128k.order = 0
+        audio_128k.props.margin_left = MARGIN_LEFT
+        audio_128k.connect('toggled', self.on_audio_toggled)
+        format_box.pack_start(audio_128k, False, False, 0)
+        audio_192k = Gtk.RadioButton(_('192K MP3'))
+        audio_192k.order = 1
+        audio_192k.join_group(audio_128k)
+        audio_192k.props.margin_left = MARGIN_LEFT
+        audio_192k.connect('toggled', self.on_audio_toggled)
+        format_box.pack_start(audio_192k, False, False, 0)
+        audio_320k = Gtk.RadioButton(_('320K MP3'))
+        audio_320k.order = 2
+        audio_320k.props.margin_left = MARGIN_LEFT
+        audio_320k.connect('toggled', self.on_audio_toggled)
+        audio_320k.join_group(audio_128k)
+        format_box.pack_start(audio_320k, False, False, 0)
+        audio_flac = Gtk.RadioButton(_('Flac Lossless (Best Quality)'))
+        audio_flac.order = 3
+        audio_flac.props.margin_left = MARGIN_LEFT
+        audio_flac.connect('toggled', self.on_audio_toggled)
+        audio_flac.join_group(audio_128k)
+        format_box.pack_start(audio_flac, False, False, 0)
+        for btn in audio_flac.get_group():
+            btn.set_active(btn.order == self.app.conf['audio'])
 
         video_label = Widgets.BoldLabel(_('Prefered Video Format'))
         video_label.props.margin_top = MARGIN_TOP
         format_box.pack_start(video_label, False, False, 0)
-        radio_mp4 = Gtk.RadioButton(_('MP4 (faster)'))
-        radio_mp4.props.margin_left = MARGIN_LEFT
-        radio_mp4.connect('toggled', self.on_video_toggled)
-        format_box.pack_start(radio_mp4, False, False, 0)
-        radio_mkv = Gtk.RadioButton(_('MKV (better)'))
-        radio_mkv.props.margin_left = MARGIN_LEFT
-        radio_mkv.join_group(radio_mp4)
-        radio_mkv.set_active(app.conf['use-mkv'])
-        radio_mkv.connect('toggled', self.on_video_toggled)
-        radio_mkv.set_tooltip_text(
-                _( 'Please use this format when using Karaoke'))
-        format_box.pack_start(radio_mkv, False, False, 0)
+        video_mp4l = Gtk.RadioButton(_('MP4L (Faster)'))
+        video_mp4l.props.margin_left = MARGIN_LEFT
+        video_mp4l.connect('toggled', self.on_video_toggled)
+        video_mp4l.order = 0
+        format_box.pack_start(video_mp4l, False, False, 0)
+        video_mp4 = Gtk.RadioButton(_('MP4 (Better)'))
+        video_mp4.props.margin_left = MARGIN_LEFT
+        video_mp4.join_group(video_mp4l)
+        video_mp4.connect('toggled', self.on_video_toggled)
+        video_mp4.order = 1
+        format_box.pack_start(video_mp4, False, False, 0)
+        video_mp4.set_active(self.app.conf['video'] == video_mp4.order)
 
         # lyrics tab
         lrc_box = NoteTab()
@@ -209,32 +228,31 @@ class Preferences(Gtk.Dialog):
         lrc_normal_text_label = Widgets.BoldLabel(_('Normal Text'))
         lrc_box.pack_start(lrc_normal_text_label, False, True, 0)
 
-        lrc_normal_text_size = FontBox(
-                _('text size'), app.conf, 'lrc-text-size', use_margin=True)
+        lrc_normal_text_size = FontBox(_('text size'), app.conf,
+                                       'lrc-text-size', use_margin=True)
         lrc_box.pack_start(lrc_normal_text_size, False, True, 0)
 
-        lrc_normal_text_color = ColorBox(
-                _('text color'), app.conf, 'lrc-text-color', use_margin=True)
+        lrc_normal_text_color = ColorBox(_('text color'), app.conf,
+                                         'lrc-text-color', use_margin=True)
         lrc_box.pack_start(lrc_normal_text_color, False, True, 0)
         lrc_normal_text_color.props.margin_bottom = 10
 
-        lrc_highlighted_text_label = Widgets.BoldLabel(
-                _('Highlighted Text'))
+        lrc_highlighted_text_label = Widgets.BoldLabel(_('Highlighted Text'))
         lrc_box.pack_start(lrc_highlighted_text_label, False, True, 0)
 
-        lrc_highlighted_text_size = FontBox(
-                _('text size'), app.conf, 'lrc-highlighted-text-size',
-                use_margin=True)
+        lrc_highlighted_text_size = FontBox(_('text size'), app.conf,
+                                            'lrc-highlighted-text-size',
+                                            use_margin=True)
         lrc_box.pack_start(lrc_highlighted_text_size, False, True, 0)
 
-        lrc_highlighted_text_color = ColorBox(
-                _('text color'), app.conf, 'lrc-highlighted-text-color',
-                use_margin=True)
+        lrc_highlighted_text_color = ColorBox(_('text color'), app.conf,
+                                              'lrc-highlighted-text-color',
+                                              use_margin=True)
         lrc_highlighted_text_color.props.margin_bottom = 10
         lrc_box.pack_start(lrc_highlighted_text_color, False, True, 0)
 
-        lrc_word_back_color = ColorBox(
-                _('Lyrics Text Background color'), app.conf, 'lrc-back-color')
+        lrc_word_back_color = ColorBox(_('Lyrics Text Background color'),
+                                       app.conf, 'lrc-back-color')
         lrc_box.pack_start(lrc_word_back_color, False, True, 0)
 
         # folders tab
@@ -243,15 +261,15 @@ class Preferences(Gtk.Dialog):
 
         song_folder_label = Widgets.BoldLabel(_('Place to store sogns'))
         folder_box.pack_start(song_folder_label, False, False, 0)
-        song_folder = ChooseFolder(
-                self, 'song-dir', _('Moving cached songs to new folder'))
+        song_folder = ChooseFolder(self, 'song-dir',
+                                   _('Moving cached songs to new folder'))
         folder_box.pack_start(song_folder, False, False, 0)
 
         mv_folder_label = Widgets.BoldLabel(_('Place to store MVs'))
         mv_folder_label.props.margin_top = MARGIN_TOP
         folder_box.pack_start(mv_folder_label, False, False, 0)
-        mv_folder = ChooseFolder(
-                self, 'mv-dir', _('Moving cached MVs to new folder'))
+        mv_folder = ChooseFolder(self, 'mv-dir',
+                                 _('Moving cached MVs to new folder'))
         folder_box.pack_start(mv_folder, False, False, 0)
 
         self.notebook = notebook
@@ -268,23 +286,21 @@ class Preferences(Gtk.Dialog):
         self.shortcut_win = Gtk.ScrolledWindow()
 
         disable_btn = Gtk.RadioButton(_('Disable Keyboard Shortcut'))
-        disable_btn.connect(
-                'toggled', self.on_shortcut_btn_toggled, ShortcutMode.NONE)
+        disable_btn.connect('toggled', self.on_shortcut_btn_toggled,
+                            ShortcutMode.NONE)
         disable_btn.set_active(curr_mode == ShortcutMode.NONE)
         box.pack_start(disable_btn, False, False, 0)
 
         default_btn = Gtk.RadioButton(_('Use Default MultiMedia Key'))
-        default_btn.connect(
-                'toggled', self.on_shortcut_btn_toggled,
-                ShortcutMode.DEFAULT)
+        default_btn.connect('toggled', self.on_shortcut_btn_toggled,
+                            ShortcutMode.DEFAULT)
         default_btn.join_group(disable_btn)
         default_btn.set_active(curr_mode == ShortcutMode.DEFAULT)
         box.pack_start(default_btn, False, False, 0)
 
         custom_btn = Gtk.RadioButton(_('Use Custom Keyboard Shortcut'))
-        custom_btn.connect(
-                'toggled', self.on_shortcut_btn_toggled,
-                ShortcutMode.CUSTOM)
+        custom_btn.connect('toggled', self.on_shortcut_btn_toggled,
+                           ShortcutMode.CUSTOM)
         custom_btn.join_group(default_btn)
         custom_btn.set_active(curr_mode == ShortcutMode.CUSTOM)
         box.pack_start(custom_btn, False, False, 0)
@@ -304,9 +320,8 @@ class Preferences(Gtk.Dialog):
 
         key_cell = Gtk.CellRendererAccel(editable=True)
         key_cell.connect('accel-edited', self.on_shortcut_key_cell_edited)
-        key_col = Gtk.TreeViewColumn(
-                'Shortcut Key', key_cell,
-                accel_key=KEY_COL, accel_mods=MOD_COL)
+        key_col = Gtk.TreeViewColumn('Shortcut Key', key_cell,
+                                     accel_key=KEY_COL, accel_mods=MOD_COL)
         tv.append_column(key_col)
         
         for name in self.app.conf['custom-shortcut']:
@@ -338,11 +353,12 @@ class Preferences(Gtk.Dialog):
 
     # format tab signal handlers
     def on_audio_toggled(self, radiobtn):
-        self.app.conf['use-ape'] = radiobtn.get_group()[0].get_active()
+        if radiobtn.get_active():
+            self.app.conf['audio'] = radiobtn.order
 
     def on_video_toggled(self, radiobtn):
-        # radio_group[0] is MKV
-        self.app.conf['use-mkv'] = radiobtn.get_group()[0].get_active()
+        if radiobtn.get_active():
+            self.app.conf['video'] = radiobtn.order
 
     def on_shortcut_btn_toggled(self, button, mode):
         if button.get_active() is False:
